@@ -197,9 +197,11 @@ where
 #[pyfunction]
 pub fn replace_all_randn_seeded(circuit: CircuitRc) -> CircuitRc {
     deep_map_unwrap(&circuit, |node| match node {
-        Circuit::ArrayConstant(ac) => ArrayConstant::randn_named_seeded(
+        Circuit::ArrayConstant(ac) => ArrayConstant::randn_seeded(
             ac.info().shape.clone(),
             ac.name_cloned(),
+            ac.info().device_dtype.clone(),
+            // We use the tensor hash instead of the circuit hash
             ac.value.hash_usize().unwrap(),
         )
         .rc(),
@@ -212,6 +214,7 @@ pub fn replace_all_randn_seeded(circuit: CircuitRc) -> CircuitRc {
                             return TensorAxisIndex::new_tensor_randint_seeded(
                                 t.shape()[0],
                                 *l,
+                                index.info().device_dtype.clone(),
                                 t.hash_usize().unwrap(),
                             );
                         }
