@@ -1,4 +1,4 @@
-use std::collections::HashMap;
+use std::{collections::HashMap, intrinsics::breakpoint};
 
 use crate::pyo3_prelude::*;
 use num_bigint::BigUint;
@@ -73,6 +73,7 @@ pub fn deep_maybe_distribute(node: &Circuit, context: &mut OptimizationContext)
             _ => None,
         },
         context,
+        &mut HashMap::new(),
     )
     .unwrap_or(node.clone().rc())
 }
