@@ -1,4 +1,5 @@
 use crate::{
+    all_imports::TorchDeviceDtypeOp,
     new_rc_unwrap,
     py_types::{PY_EINSUM, PY_MAKE_DIAGONAL},
     pyo3_prelude::*,
@@ -887,19 +888,16 @@ impl CircuitNode for Index {
         })
     }
 
-    // commented this out bc cast_circuit is broken with this bc deep_map assumes you can construct
-    // original with new children
-    //
-    // fn device_dtype_extra<'a>(&'a self) -> Box<dyn Iterator<Item = TorchDeviceDtypeOp> + 'a> {
-    //     Box::new(self.index.0.iter().filter_map(|x| match x {
-    //         TensorAxisIndex::Tensor(tensor) if !tensor.shape().is_empty() => {
-    //             let mut out: TorchDeviceDtypeOp = TorchDeviceDtype::from_tensor(tensor).into();
-    //             out.dtype = None;
-    //             Some(out)
-    //         }
-    //         _ => None,
-    //     }))
-    // }
+    fn device_dtype_extra<'a>(&'a self) -> Box<dyn Iterator<Item = TorchDeviceDtypeOp> + 'a> {
+        Box::new(self.index.0.iter().filter_map(|x| match x {
+            TensorAxisIndex::Tensor(tensor) if !tensor.shape().is_empty() => {
+                let mut out: TorchDeviceDtypeOp = TorchDeviceDtype::from_tensor(tensor).into();
+                out.dtype = None;
+                Some(out)
+            }
+            _ => None,
+        }))
+    }
 }
 
 impl CircuitNodeAutoName for Index {
