@@ -1,7 +1,8 @@
 use crate::{new_rc, pyo3_prelude::*};
 use macro_rules_attribute::apply;
 use num_bigint::BigUint;
-use pyo3::types::PyTuple;
+use pyo3::types::{IntoPyDict, PyTuple};
+use std::collections::HashMap;
 use uuid::Uuid;
 
 use super::{
@@ -109,13 +110,34 @@ impl ArrayConstant {
     }
 
     #[staticmethod]
-    pub fn randn_named(shape: Vec<usize>, name: Option<String>) -> Self {
+    pub fn new_named_axes(value: Tensor, name: Option<String>, named_axes: NamedAxes) -> Self {
+        let result = Self::new(value, name);
+        set_named_axes(&result, named_axes)
+    }
+
+    #[staticmethod]
+    pub fn randn_named(
+        shape: Vec<usize>,
+        name: Option<String>,
+        device_dtype: TorchDeviceDtypeOp,
+    ) -> Self {
         Python::with_gil(|py| {
+            let mut kwargs = HashMap::new();
+            if let Some(dtype) = device_dtype.dtype {
+                kwargs.insert("dtype", PY_TORCH.getattr(py, dtype).unwrap());
+            }
+            if let Some(device) = device_dtype.device {
+                kwargs.insert("device", device.into_py(py));
+            }
             ArrayConstant::new(
                 PY_TORCH
                     .getattr(py, "randn")
                     .unwrap()
-                    .call(py, (PyTuple::new(py, shape),), None)
+                    .call(
+                        py,
+                        (PyTuple::new(py, shape),),
+                        Some(kwargs.into_py_dict(py)),
+                    )
                     .unwrap()
                     .extract(py)
                     .unwrap(),
@@ -127,11 +149,16 @@ impl ArrayConstant {
     #[staticmethod]
     #[args(args = "*")]
     pub fn randn(args: Vec<usize>) -> Self {
-        ArrayConstant::randn_named(args, None)
+        ArrayConstant::randn_named(args, None, TorchDeviceDtypeOp::default())
     }
 
     #[staticmethod]
-    pub fn randn_named_seeded(shape: Vec<usize>, name: Option<String>, seed: usize) -> Self {
+    pub fn randn_seeded(
+        shape: Vec<usize>,
+        name: Option<String>,
+        device_dtype: TorchDeviceDtypeOp,
+        seed: usize,
+    ) -> Self {
         Python::with_gil(|py| {
             PY_TORCH
                 .getattr(py, "manual_seed")
@@ -139,13 +166,7 @@ impl ArrayConstant {
                 .call(py, (seed,), None)
                 .unwrap();
         });
-        ArrayConstant::randn_named(shape, name)
-    }
-
-    #[staticmethod]
-    pub fn new_named_axes(value: Tensor, name: Option<String>, named_axes: NamedAxes) -> Self {
-        let result = Self::new(value, name);
-        set_named_axes(&result, named_axes)
+        Self::randn_named(shape, name, device_dtype)
     }
 }
 
