@@ -1,3 +1,4 @@
+use crate::all_imports::TorchDeviceDtypeOp;
 use crate::pyo3_prelude::*;
 use std::{collections::HashMap, iter::zip};
 
@@ -357,9 +358,15 @@ fn test_generalfuction() {
         vec![(
             Add::nrc(
                 vec![
-                    ArrayConstant::randn(vec![2, 3, 4]).rc(),
+                    ArrayConstant::randn_named(vec![2, 3, 4], None, TorchDeviceDtypeOp::default())
+                        .rc(),
                     GeneralFunction::new_by_name(
-                        vec![ArrayConstant::randn(vec![2, 3, 4]).rc()],
+                        vec![ArrayConstant::randn_named(
+                            vec![2, 3, 4],
+                            None,
+                            TorchDeviceDtypeOp::default(),
+                        )
+                        .rc()],
                         "sigmoid".to_owned(),
                         None,
                     )
