@@ -1063,15 +1063,25 @@ where
     }
 }
 
-pub fn deep_map_op_context<F, C>(circuit: &Circuit, f: &F, context: &mut C) -> Option<CircuitRc>
+pub fn deep_map_op_context<F, C>(
+    circuit: &Circuit,
+    f: &F,
+    context: &mut C,
+    self_cache: &mut HashMap<HashBytes, Option<CircuitRc>>,
+) -> Option<CircuitRc>
 where
     F: Fn(&Circuit, &mut C) -> Option<CircuitRc>,
 {
-    let inner_mapped = circuit.map_children_op(|x| deep_map_op_context(x, f, context));
-    match inner_mapped {
+    if let Some(z) = self_cache.get(&circuit.info().hash) {
+        return z.clone();
+    }
+    let inner_mapped = circuit.map_children_op(|x| deep_map_op_context(x, f, context, self_cache));
+    let result = match inner_mapped {
         Some(z) => f(&z, context).or(Some(z.rc())),
         None => f(&circuit, context),
-    }
+    };
+    self_cache.insert(circuit.info().hash, result.clone());
+    result
 }
 
 pub fn evaluate_fn_uncached(
