@@ -115,9 +115,10 @@ pub fn repr_circuit_one_level(circuit: &CircuitRc, context: &HashMap<CircuitRc,
             )
         }
         Circuit::ArrayConstant(a) => format!(
-            "ArrayConstant::randn_named_seeded({}, {}, {}).rc()",
+            "ArrayConstant::randn_seeded({}, {}, {}, {}).rc()",
             a.compute_shape().repr(),
             a.name_cloned().repr(),
+            a.info().device_dtype.repr(),
             a.value.hash_usize().unwrap(),
         ),
         Circuit::Symbol(s) => format!(
@@ -151,7 +152,8 @@ pub fn repr_circuit_one_level(circuit: &CircuitRc, context: &HashMap<CircuitRc,
         Circuit::Index(i) => format!(
             "Index::nrc({}, {}, {})",
             node_string(&i.node),
-            i.index.repr(i.node.info().shape.clone()),
+            i.index
+                .repr(i.node.info().shape.clone(), &i.info().device_dtype),
             i.name_cloned().repr()
         ),
         Circuit::GeneralFunction(g) => {
@@ -181,7 +183,7 @@ pub fn repr_circuit_one_level(circuit: &CircuitRc, context: &HashMap<CircuitRc,
                 "Scatter::nrc({}, {}, {}, {})",
                 node_string(&s.node),
                 // indices are into the output zero-padded array, so we use the shape of s instead of s.node
-                s.index.repr(s.info().shape.clone()),
+                s.index.repr(s.info().shape.clone(), &s.info().device_dtype),
                 s.compute_shape().repr(),
                 s.name_cloned().repr()
             )
@@ -189,8 +191,11 @@ pub fn repr_circuit_one_level(circuit: &CircuitRc, context: &HashMap<CircuitRc,
     }
 }
 
-/// Prints out a string of Rust code representing an expression that evaluates to the
-/// circuit provided
+/// Prints out a string of Rust code representing an expression that evaluates to something similar
+/// to circuit provided. Currently it ablates array constants and int tensors for tensor indexing
+/// with seeded randn tensors, so the evaluation may be different. This transformation is not invariant
+/// to some rewrites as a result.
+///
 /// There's an analogous Python function, interp.circuit.print_circuit.lambda_notation_circuit
 ///
 /// Python example:
