@@ -394,13 +394,8 @@ pub fn order_to_schedule(
     constants: &Vec<ArrayConstant>,
     scalar_constants: &Vec<ScalarConstant>,
     to_keep: HashSet<HashBytes>,
+    device_dtype: TorchDeviceDtype,
 ) -> Schedule {
-    let device_dtype = get_compatible_dtype(
-        &*order
-            .iter()
-            .last()
-            .unwrap_or(&Symbol::new_with_random_uuid(vec![], None).rc()),
-    );
     let mut result: Schedule = Schedule {
         instructions: vec![],
         constants: constants
@@ -641,6 +636,7 @@ pub fn circuit_to_schedule(
             .iter()
             .map(|x| dag.node_hashes[*x])
             .collect(),
+        get_compatible_dtype(&circuit),
     );
 
     Ok(out)
@@ -653,6 +649,7 @@ pub fn circuit_to_schedule_naive_toposort(circuit: CircuitRc) -> Schedule {
         &vec![],
         &vec![],
         HashSet::from([circuit.info().hash]),
+        get_compatible_dtype(&circuit),
     )
 }
 
